summary refs log tree commit diff
path: root/pkgs/tools/networking/p2p
diff options
context:
space:
mode:
authorAndersonTorres <torres.anderson.85@protonmail.com>2021-10-21 16:58:06 -0300
committerAndersonTorres <torres.anderson.85@protonmail.com>2021-10-21 19:31:52 -0300
commit87cb00aaefbe1dcf929ebc029067047c8c01e67f (patch)
tree93488d6918a08599f445f376e2ae6b497744fded /pkgs/tools/networking/p2p
parent3199dc10b71f0cfede08e8acaf8603596e03d98c (diff)
rakshasa.libtorrent: 0.13.8 -> 0.13.8+date=2021-08-07
Diffstat (limited to 'pkgs/tools/networking/p2p')
-rw-r--r--pkgs/tools/networking/p2p/rakshasa-rtorrent/libtorrent.nix44
1 files changed, 31 insertions, 13 deletions
diff --git a/pkgs/tools/networking/p2p/rakshasa-rtorrent/libtorrent.nix b/pkgs/tools/networking/p2p/rakshasa-rtorrent/libtorrent.nix
index 9a635512f04f8..fff4cbb36cf62 100644
--- a/pkgs/tools/networking/p2p/rakshasa-rtorrent/libtorrent.nix
+++ b/pkgs/tools/networking/p2p/rakshasa-rtorrent/libtorrent.nix
@@ -1,30 +1,48 @@
-# NOTE: this is rakshava's version of libtorrent, used mainly by rtorrent
-# This is NOT libtorrent-rasterbar, used by Deluge, qbitttorent, and others
-{ lib, stdenv, fetchFromGitHub, pkg-config, autoreconfHook
-, cppunit, openssl, libsigcxx, zlib
+# Note: this is rakshasa's version of libtorrent, used mainly by rtorrent.
+# *Do not* mistake it by libtorrent-rasterbar, used by Deluge, qbitttorent etc.
+{ lib
+, stdenv
+, fetchFromGitHub
+, autoconf-archive
+, autoreconfHook
+, cppunit
+, libsigcxx
+, openssl
+, pkg-config
+, zlib
 }:
 
 stdenv.mkDerivation rec {
-  pname = "libtorrent";
-  version = "0.13.8";
+  pname = "rakshasa-libtorrent";
+  version = "0.13.8+date=2021-08-07";
 
   src = fetchFromGitHub {
     owner = "rakshasa";
-    repo = pname;
-    rev = "v${version}";
-    sha256 = "1h5y6ab3gs20yyprdfwcw8fh1c6czs4yrdj0kf54d2vp9qwz685r";
+    repo = "libtorrent";
+    rev = "53596afc5fae275b3fb5753a4bb2a1a7f7cf6a51";
+    hash = "sha256-gyl/jfbptHz/gHkkVGWShhv1Z7o9fa9nJIz27U2A6wg=";
   };
 
-  nativeBuildInputs = [ pkg-config autoreconfHook ];
-  buildInputs = [ cppunit openssl libsigcxx zlib ];
+  nativeBuildInputs = [
+    autoconf-archive
+    autoreconfHook
+    pkg-config
+  ];
+
+  buildInputs = [
+    cppunit
+    libsigcxx
+    openssl
+    zlib
+  ];
 
   enableParallelBuilding = true;
 
   meta = with lib; {
     homepage = "https://github.com/rakshasa/libtorrent";
     description = "A BitTorrent library written in C++ for *nix, with focus on high performance and good code";
-
-    platforms = platforms.unix;
+    license = licenses.gpl2Plus;
     maintainers = with maintainers; [ ebzzry codyopel ];
+    platforms = platforms.unix;
   };
 }